diff --git a/osu.Game/Overlays/Mods/ModSelectOverlay.cs b/osu.Game/Overlays/Mods/ModSelectOverlay.cs
index 9ce79c25f7..cf57322594 100644
--- a/osu.Game/Overlays/Mods/ModSelectOverlay.cs
+++ b/osu.Game/Overlays/Mods/ModSelectOverlay.cs
@@ -369,7 +369,7 @@ namespace osu.Game.Overlays.Mods
foreach (var section in ModSectionsContainer)
{
- section.FlushAnimation();
+ section.FlushPendingSelections();
}
FooterContainer.MoveToX(content_width, WaveContainer.DISAPPEAR_DURATION, Easing.InSine);
diff --git a/osu.Game/Overlays/Mods/ModSelectScreen.cs b/osu.Game/Overlays/Mods/ModSelectScreen.cs
index bb12143d7c..8060bca65f 100644
--- a/osu.Game/Overlays/Mods/ModSelectScreen.cs
+++ b/osu.Game/Overlays/Mods/ModSelectScreen.cs
@@ -308,7 +308,7 @@ namespace osu.Game.Overlays.Mods
var column = columnFlow[i].Column;
- column.FlushAnimation();
+ column.FlushPendingSelections();
column.TopLevelContent
.MoveToY(i % 2 == 0 ? -distance : distance, fade_out_duration, Easing.OutQuint)
.FadeOut(fade_out_duration, Easing.OutQuint);
diff --git a/osu.Game/Overlays/Mods/ModColumn.cs b/osu.Game/Overlays/Mods/ModColumn.cs
index f9332dd28b..a792c0a81e 100644
--- a/osu.Game/Overlays/Mods/ModColumn.cs
+++ b/osu.Game/Overlays/Mods/ModColumn.cs
@@ -435,9 +435,9 @@ namespace osu.Game.Overlays.Mods
}
///
/// Play out all remaining animations immediately to leave mods in a good (final) state.
///
- public void FlushAnimation()
+ public void FlushPendingSelections()
{
while (pendingSelectionOperations.TryDequeue(out var dequeuedAction))
dequeuedAction();
@@ -435,9 +435,9 @@ namespace osu.Game.Overlays.Mods
}
///
- /// Play out all remaining animations immediately to leave mods in a good (final) state.
+ /// Run any delayed selections (due to animation) immediately to leave mods in a good (final) state.
///
diff --git a/osu.Game/Overlays/Mods/ModSection.cs b/osu.Game/Overlays/Mods/ModSection.cs
index 5bf8cddd0c..a70191a864 100644
--- a/osu.Game/Overlays/Mods/ModSection.cs
+++ b/osu.Game/Overlays/Mods/ModSection.cs
@@ -250,9 +250,9 @@ namespace osu.Game.Overlays.Mods
protected virtual ModButton CreateModButton(Mod mod) => new ModButton(mod);
///
/// Play out all remaining animations immediately to leave mods in a good (final) state.
///
- public void FlushAnimation()
+ public void FlushPendingSelections()
{
while (pendingSelectionOperations.TryDequeue(out var dequeuedAction))
dequeuedAction();
@@ -250,9 +250,9 @@ namespace osu.Game.Overlays.Mods
protected virtual ModButton CreateModButton(Mod mod) => new ModButton(mod);
///
- /// Play out all remaining animations immediately to leave mods in a good (final) state.
+ /// Run any delayed selections (due to animation) immediately to leave mods in a good (final) state.
///